@@ -209,6 +209,11 @@ class _CreateLoadQuantiles(DoFn):
         # Iterate through loads
         for i, row in df.iterrows():
 
+            pd.to_numeric(df['weight'], errors='coerce')
+            pd.to_numeric(df['price'], errors='coerce')
+            pd.to_numeric(df['per_mile_rate'], errors='coerce')
+            pd.to_numeric(df['distance'], errors='coerce')
+
             pickup_state = row["pickup_state"]
             dropoff_state = row["dropoff_state"]
             if row["equipment_type_list"]:
